@@ -322,7 +322,11 @@ impl<'a, I: Tokens> Parser<I> {
             })));
         }
 
-        if (self.ctx().in_async || self.syntax().top_level_await()) && is!(self, "await") {
+        if is!(self, "await") {
+            let ctx = self.ctx();
+            if ctx.in_function && !ctx.in_async {
+                self.emit_err(self.input.cur_span(), SyntaxError::AwaitInFunction);
+            }
             return self.parse_await_expr();
         }
 
