@@ -363,7 +363,7 @@ impl<I: Tokens> Parser<I> {
 
         let start = cur_pos!(self);
 
-        let name = self.parse_ident_name()?;
+        let name = self.in_type().parse_ident_name()?;
         let constraint = self.eat_then_parse_ts_type(&tok!("extends"))?;
         let default = self.eat_then_parse_ts_type(&tok!('='))?;
 
@@ -525,6 +525,8 @@ impl<I: Tokens> Parser<I> {
         eat_colon: bool,
         start: BytePos,
     ) -> PResult<TsTypeAnn> {
+        trace_cur!(self, parse_ts_type_ann);
+
         debug_assert!(self.input.syntax().typescript());
 
         self.in_type().parse_with(|p| {
@@ -532,6 +534,8 @@ impl<I: Tokens> Parser<I> {
                 assert_and_bump!(p, ':');
             }
 
+            trace_cur!(p, parse_ts_type_ann__after_colon);
+
             let type_ann = p.parse_ts_type()?;
 
             Ok(TsTypeAnn {
